import { select, scaleLinear, scaleBand, max, format } from 'd3';
import { data } from './data';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const xValue = d => d['Population 2018'];

const xScale = scaleLinear()
  .domain([0, max(data, xValue)])
  .range([0, width]);

const yValue = d => d['Continent'];

const yScale = scaleBand()
  .domain(data.map(yValue))
  .range([0, height])
  .padding(0.5);

svg.selectAll('rect').data(data)
  .enter().append('rect')
    .attr('y', d => yScale(yValue(d)))
    .attr('width', d => xScale(xValue(d)))
    .attr('height', yScale.bandwidth());

const commaFormat = format(',');

svg.selectAll('text').data(data)
  .enter().append('text')
    .attr('y', d => yScale(yValue(d)) - 3)
    .text(d => `${yValue(d)}: ${commaFormat(xValue(d))}`);